@@ -12,12 +12,13 @@
 # Reaper Scans [EN] (disabled)
 # The Nonames Scans [EN] (disabled)
 
-from bs4 import BeautifulSoup
 import json
+
+from bs4 import BeautifulSoup
 import requests
 
+from komikku.consts import USER_AGENT
 from komikku.servers import Server
-from komikku.servers import USER_AGENT
 from komikku.servers.utils import convert_date_string
 from komikku.utils import get_buffer_mime_type
 
